{% extends "base/index.md" %}
{% block content %}

## Documentation

Visit [Read the Docs](https://{{ package_name }}.readthedocs.org) for the full documentation, including overviews and several examples.

{% endblock %}
